﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="ConditionType.cs" company="CodePlex">
//   Copyright © CodePlex 2012
// </copyright>
// <summary>
//   Defines the ConditionType type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace DataFramework.QueryConditions
{
    /// <summary>
    /// A condition type that will be defined when a query is built.
    /// </summary>
    public enum ConditionType
    {
        /// <summary>
        /// The query condition is unknown
        /// </summary>
        Unknown,

        /// <summary>
        /// Equality query condition
        /// </summary>
        Equal,

        /// <summary>
        /// Non-equality query condition.
        /// </summary>
        NotEqual,

        /// <summary>
        /// Greater Than query condition.
        /// </summary>
        GreaterThan,

        /// <summary>
        /// Less Than query condition.
        /// </summary>
        LessThan,

        /// <summary>
        /// Greater Than or Equal query condition.
        /// </summary>
        GreaterThanOrEqual,

        /// <summary>
        /// Less Than or Equal query condition.
        /// </summary>
        LessThanOrEqual,

        /// <summary>
        /// Between query condition.
        /// </summary>
        Between,

        /// <summary>
        /// Like query condition.
        /// </summary>
        Like,

        /// <summary>
        /// In query condition.
        /// </summary>
        In,

        /// <summary>
        /// Is query condition.
        /// </summary>
        Is,

        /// <summary>
        /// And query condition.
        /// </summary>
        And,

        /// <summary>
        /// Or query condition.
        /// </summary>
        Or,
    }
}